@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2017 openpyxl
 
 import pytest
 
@@ -15,6 +15,7 @@ from openpyxl.xml.constants import SHEET_MAIN_NS
 from openpyxl.cell import Cell
 from openpyxl.utils.indexed_list import IndexedList
 from openpyxl.worksheet import Worksheet
+from openpyxl.packaging.relationship import Relationship, RelationshipList
 
 
 def test_get_xml_iter():
@@ -645,3 +646,25 @@ def test_sheet_format(WorkSheetParser):
 
     assert parser.ws.sheet_format.defaultRowHeight == 14.25
     assert parser.ws.sheet_format.baseColWidth == 15
+
+
+def test_tables(WorkSheetParser):
+    src = """
+    <sheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main"
+      xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships">
+      <tableParts count="1">
+        <tablePart r:id="rId1"/>
+      </tableParts>
+    </sheet>
+    """
+
+    parser = WorkSheetParser
+    r = Relationship(type="table", Id="rId1", Target="../tables/table1.xml")
+    rels = RelationshipList()
+    rels.append(r)
+    parser.ws._rels = rels
+
+    parser.source = src
+    parser.parse()
+
+    assert parser.tables == ["../tables/table1.xml"]
