@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2017 openpyxl
 
 import datetime
 from io import BytesIO
@@ -85,6 +85,12 @@ def test_calculate_dimension(datadir):
     sheet2 = wb['Sheet2 - Numbers']
     assert sheet2.calculate_dimension() == 'D1:AA30'
 
+def test_nonstandard_name(datadir):
+    datadir.join('reader').chdir()
+
+    wb = load_workbook(filename="nonstandard_workbook_name.xlsx", read_only=True)
+    assert wb.sheetnames == ['Sheet1']
+
 
 @pytest.mark.parametrize("filename",
                          ["sheet2.xml",
