@@ -1,11 +1,14 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2017 openpyxl
 
 """ Read worksheets on-demand
 """
 
 # compatibility
-from openpyxl.compat import range
+from openpyxl.compat import (
+    range,
+    deprecated
+)
 
 # package
 from openpyxl.cell.text import Text
@@ -95,7 +98,12 @@ class ReadOnlyWorksheet(object):
         self._xml = value
 
 
+    @deprecated("Use ws.iter_rows()")
     def get_squared_range(self, min_col, min_row, max_col, max_row):
+        return self._cells_by_row(min_col, min_row, max_col, max_row)
+
+
+    def _cells_by_row(self, min_col, min_row, max_col, max_row):
         """
         The source worksheet file may have columns or rows missing.
         Missing cells will be created.
@@ -189,6 +197,10 @@ class ReadOnlyWorksheet(object):
         return self.iter_rows()
 
 
+    def __iter__(self):
+        return self.iter_rows()
+
+
     def calculate_dimension(self, force=False):
         if not all([self.max_column, self.max_row]):
             if force:
